<?php

namespace Drupal\consent_manager_cmp\Form;

use Drupal\consent_manager\Form\SettingsBaseForm;
use Drupal\consent_manager_cmp\Plugin\ConsentManager\Cmp;
use Drupal\Core\Form\FormStateInterface;

/**
 * Form for the Cookie Banner settings.
 */
class SettingsForm extends SettingsBaseForm {

  /**
   * {@inheritdoc}
   */
  protected function getPluginType() {
    return 'cmp';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildForm($form, $form_state);
    $path = '/' . $this->moduleExtensionList->getPath('consent_manager_cmp');

    $form['manual']['blocking'] = [
      '#type' => 'select',
      '#title' => $this->t('Blocking mode'),
      '#options' => [
        'automatic' => $this->t('Automatic blocking'),
        'semi-automatic' => $this->t('Semi-Automatic blocking'),
      ],
      '#config_target' => 'consent_manager_cmp.settings:blocking',
      '#required' => TRUE,
    ];

    $form['manual']['codeid'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Code-ID'),
      '#description' => $this->t('If you do not yet have an Code-ID, please get in on <a href=":url" target="_blank">www.consentmanager.net</a>', [':url' => 'https://app.consentmanager.net']),
      '#config_target' => 'consent_manager_cmp.settings:codeid',
      '#required' => TRUE,
    ];

    $form['manual']['codeid_image'] = [
      '#type' => 'html_tag',
      '#tag' => 'img',
      '#attributes' => [
        'src' => $path . '/images/codeid.png',
        'width' => '500',
        'height' => 'auto',
      ],
    ];

    $form['manual']['host'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Host'),
      '#description' => $this->t('Leave blank to use the default value: %default_value. You need to specify the host name value only (without the protocol https://).', ['%default_value' => Cmp::DEFAULT_HOST]),
      '#config_target' => 'consent_manager_cmp.settings:host',
    ];

    $form['manual']['host_image'] = [
      '#type' => 'html_tag',
      '#tag' => 'img',
      '#attributes' => [
        'src' => $path . '/images/host.png',
        'width' => '500',
        'height' => 'auto',
      ],
    ];

    $form['manual']['cdn'] = [
      '#type' => 'textfield',
      '#title' => $this->t('CDN'),
      '#description' => $this->t('Leave blank to use the default value: %default_value. You need to specify the host name value only (without the protocol https://).', ['%default_value' => Cmp::DEFAULT_CDN]),
      '#config_target' => 'consent_manager_cmp.settings:cdn',
    ];

    $form['manual']['cdn_image'] = [
      '#type' => 'html_tag',
      '#tag' => 'img',
      '#attributes' => [
        'src' => $path . '/images/cdn.png',
        'width' => '500',
        'height' => 'auto',
      ],
    ];

    $form['manual']['custom_code'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Custom HTML code'),
      '#description' => $this->t('Additional HTML code: appears before the consent manager integration markup.'),
      '#config_target' => 'consent_manager_cmp.settings:custom_code',
    ];

    $form['info'] = [
      '#type' => 'details',
      '#title' => $this->t('Info'),
      '#open' => TRUE,
      '#weight' => -100,
    ];

    $form['info']['text'] = [
      '#type' => 'item',
      '#markup' => $this->t('You can change the cookie banner design and settings at any time in the <a href=":url" target="_blank">consentmanager.net</a>.', [':url' => 'https://app.consentmanager.net']),
    ];

    return $form;
  }

}
