<?php

declare(strict_types=1);

namespace Drupal\consent_manager_cmp\Plugin\ConsentManager;

use Drupal\Component\Render\FormattableMarkup;
use Drupal\consent_manager\Attribute\ConsentManager;
use Drupal\consent_manager\ConsentManagerPluginPluginBase;
use Drupal\Core\StringTranslation\TranslatableMarkup;

/**
 * Plugin implementation of the consent_manager.
 */
#[ConsentManager(
  id: 'cmp',
  label: new TranslatableMarkup('Cookie Banner'),
  description: new TranslatableMarkup('A cookie banner is a pop-up notice that appears when a user visits a website for the first time.'),
  has_block: FALSE,
)]
final class Cmp extends ConsentManagerPluginPluginBase {

  /**
   * Automatic code markup.
   */
  protected const AUTOMATIC_CODE = '<script type="text/javascript" data-cmp-ab="1" src="https://@cdn/delivery/autoblocking/@codeid.js" data-cmp-host="@host" data-cmp-cdn="@cdn" data-cmp-codesrc="0"></script>';

  /**
   * Semi-automatic code markup.
   */
  protected const SEMI_AUTOMATIC_CODE = '<script type="text/javascript" data-cmp-ab="1" src="https://@cdn/delivery/js/semiautomatic.min.js" data-cmp-cdid="@codeid" data-cmp-host="@host" data-cmp-cdn="@cdn" data-cmp-codesrc="0"></script>';

  /**
   * {@inheritdoc}
   */
  public function getCode() {
    $code = FALSE;

    if ($code_id = $this->configuration['codeid'] ?? NULL) {
      $custom_code = $this->configuration['custom_code'];
      $default_code = $this->configuration['blocking'] === 'automatic' ? self::AUTOMATIC_CODE : self::SEMI_AUTOMATIC_CODE;

      $code = new FormattableMarkup($custom_code . $default_code, [
        '@codeid' => $code_id,
        '@host' => $this->configuration['host'] ?: self::DEFAULT_HOST,
        '@cdn' => $this->configuration['cdn'] ?: self::DEFAULT_CDN,
      ]);
    }

    return $code;
  }

}
