<?php

namespace Drupal\Tests\consent_manager_cmp\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * Simple test to ensure that main page loads with module enabled.
 *
 * @group consent_manager_cmp
 */
class LoadTest extends BrowserTestBase {

  /**
   * Test CMP ID value.
   */
  public const CDID = 'aaaaaaaaaaaa';

  /**
   * Test HOST value.
   */
  public const HOST = 'delivery.consentmanager.net';

  /**
   * Test CDN value.
   */
  public const CDN = 'cdn.consentmanager.net';

  /**
   * {@inheritdoc}
   */
  protected static $modules = ['consent_manager_cmp'];

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    $this->config('system.site')
      ->set('name', 'consentmanager')
      ->save(TRUE);
  }

  /**
   * Automatic code test.
   *
   * Tests that the home page loads with a 200 response and with automatic code.
   */
  public function testAutomaticCode() {
    $this->config('consent_manager_cmp.settings')
      ->set('codeid', self::CDID)
      ->set('host', self::HOST)
      ->set('cdn', self::CDN)
      ->set('blocking', 'automatic')
      ->set('custom_code', '<meta name="consentmanager" content="custom_code" />')
      ->save();
    $this->drupalGet('<front>');
    $this->assertSession()->statusCodeEquals(200);
    $this->assertSession()->responseContains('https://' . self::CDN . '/delivery/autoblocking/' . self::CDID . '.js');
    $this->assertSession()->responseContains('data-cmp-host="' . self::HOST . '"');
    $this->assertSession()->responseContains('data-cmp-cdn="' . self::CDN . '"');
    $xpath = $this->xpath('//head/meta[@name="consentmanager"]');
    self::assertNotEmpty($xpath, 'Consent Manager custom code markup not found.');
  }

  /**
   * Semi-automatic code test.
   *
   * Tests that the home page loads with a 200 response and with
   * semi-automatic code.
   */
  public function testSemiAutomaticCode() {
    $this->config('consent_manager_cmp.settings')
      ->set('codeid', self::CDID)
      ->set('host', self::HOST)
      ->set('cdn', self::CDN)
      ->set('blocking', 'semi_automatic')
      ->set('custom_code', '<div name="consentmanager" content="custom_code"></div>')
      ->save();
    $this->drupalGet('<front>');
    $this->assertSession()->statusCodeEquals(200);
    $this->assertSession()->responseContains('data-cmp-cdid="' . self::CDID . '"');
    $this->assertSession()->responseContains('data-cmp-host="' . self::HOST . '"');
    $this->assertSession()->responseContains('data-cmp-cdn="' . self::CDN . '"');
    $xpath = $this->xpath('//body/div[@name="consentmanager"]');
    self::assertNotEmpty($xpath, 'Consent Manager custom code markup not found.');
  }

}
