<?php

namespace Drupal\consent_manager_pcp\Form;

use Drupal\consent_manager\Form\SettingsBaseForm;
use Drupal\consent_manager_pcp\Plugin\ConsentManager\Pcp;
use Drupal\Core\Form\FormStateInterface;

/**
 * Form for the PCP Tool settings.
 */
class SettingsForm extends SettingsBaseForm {

  /**
   * {@inheritdoc}
   */
  protected function getPluginType() {
    return 'pcp';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildForm($form, $form_state);
    $path = '/' . $this->moduleExtensionList->getPath('consent_manager_pcp');

    $form['manual']['codeid'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Code-ID'),
      '#description' => $this->t('If you do not yet have an Code-ID, please get in on <a href=":url" target="_blank">www.consentmanager.net</a>', [':url' => 'https://app.consentmanager.net']),
      '#config_target' => 'consent_manager_pcp.settings:codeid',
      '#required' => TRUE,
    ];

    $form['manual']['codeid_image'] = [
      '#type' => 'html_tag',
      '#tag' => 'img',
      '#attributes' => [
        'src' => $path . '/images/codeid.png',
        'width' => '500',
        'height' => 'auto',
      ],
    ];

    $form['manual']['host'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Host'),
      '#description' => $this->t('Leave blank to use the default value: %default_value. You need to specify the host name value only (without the protocol https://).', ['%default_value' => Pcp::DEFAULT_HOST]),
      '#config_target' => 'consent_manager_pcp.settings:host',
    ];

    $form['manual']['host_image'] = [
      '#type' => 'html_tag',
      '#tag' => 'img',
      '#attributes' => [
        'src' => $path . '/images/host.png',
        'width' => '500',
        'height' => 'auto',
      ],
    ];

    $form['info'] = [
      '#type' => 'details',
      '#title' => $this->t('Info'),
      '#open' => TRUE,
      '#weight' => -100,
    ];

    $form['info']['text'] = [
      '#type' => 'item',
      '#markup' => $this->t('You need to place the <strong>Privacy Policy Generator</strong> block on the desired page.'),
    ];

    return $form;
  }

}
