<?php

declare(strict_types=1);

namespace Drupal\consent_manager;

use Drupal\consent_manager\Attribute\ConsentManager;
use Drupal\Core\Cache\CacheBackendInterface;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Plugin\DefaultPluginManager;

/**
 * ConsentManager plugin manager.
 */
final class ConsentManagerPluginManager extends DefaultPluginManager {

  /**
   * The config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected ConfigFactoryInterface $configFactory;

  /**
   * Constructs the object.
   */
  public function __construct(\Traversable $namespaces, CacheBackendInterface $cache_backend, ModuleHandlerInterface $module_handler, ConfigFactoryInterface $config_factory) {
    parent::__construct('Plugin/ConsentManager', $namespaces, $module_handler, ConsentManagerPluginInterface::class, ConsentManager::class);
    $this->alterInfo('consent_manager_info');
    $this->setCacheBackend($cache_backend, 'consent_manager_plugins');
    $this->configFactory = $config_factory;
  }

  /**
   * {@inheritdoc}
   */
  public function createInstance($plugin_id, array $configuration = []) {
    if (!$configuration) {
      $configuration = (array) $this->configFactory->get('consent_manager_' . $plugin_id . '.settings')->get();
    }

    return parent::createInstance($plugin_id, $configuration);
  }

  /**
   * Gets plugins with block definitions.
   *
   * @return array
   *   An array of plugin definitions.
   */
  public function getBlockDefinitions() {
    return array_filter($this->getDefinitions(), static fn($definition) => $definition['has_block']);
  }

}
