<?php

declare(strict_types=1);

namespace Drupal\consent_manager;

use Drupal\Component\Plugin\PluginBase;
use Drupal\Component\Render\FormattableMarkup;

/**
 * Base class for consent_manager plugins.
 */
abstract class ConsentManagerPluginPluginBase extends PluginBase implements ConsentManagerPluginInterface {

  /**
   * Default host.
   */
  public const DEFAULT_HOST = 'delivery.consentmanager.net';

  /**
   * Default CDN.
   */
  public const DEFAULT_CDN = 'cdn.consentmanager.net';

  /**
   * {@inheritdoc}
   */
  public function label(): string {
    // Cast the label to a string since it is a TranslatableMarkup object.
    return (string) $this->pluginDefinition['label'];
  }

  /**
   * Gets configuration.
   *
   * @return array
   *   The configuration array.
   */
  public function getConfiguration() {
    return $this->configuration;
  }

  /**
   * {@inheritdoc}
   */
  public function getCode() {
    $code = FALSE;

    if ($code_id = $this->configuration['codeid'] ?? NULL) {
      $code = new FormattableMarkup(static::CODE, [
        '@codeid' => $code_id,
        '@host' => $this->configuration['host'] ?? static::DEFAULT_HOST,
      ]);
    }

    return $code;
  }

}
