<?php

declare(strict_types=1);

namespace Drupal\consent_manager\Plugin\Block;

use Drupal\consent_manager\ConsentManagerPluginManager;
use Drupal\consent_manager\Plugin\Derivative\ConsentManagerBlock as ConsentManagerBlockDeriver;
use Drupal\Core\Block\Attribute\Block;
use Drupal\Core\Block\BlockBase;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a generic consentmanager block.
 */
#[Block(
  id: "consent_manager",
  admin_label: new TranslatableMarkup("consentmanager Block"),
  category: new TranslatableMarkup("consentmanager"),
  deriver: ConsentManagerBlockDeriver::class,
)]
class ConsentManagerBlock extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition): self {
    return new self(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('plugin.manager.consent_manager'),
    );
  }

  /**
   * Constructs the plugin instance.
   */
  public function __construct(
    array $configuration,
    $plugin_id,
    $plugin_definition,
    private readonly ConsentManagerPluginManager $pluginManagerConsentManager,
  ) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
  }

  /**
   * {@inheritdoc}
   */
  public function build(): array {
    $build = [];
    $plugin_id = $this->getDerivativeId();
    /** @var \Drupal\consent_manager\ConsentManagerPluginInterface $plugin */
    $plugin = $this->pluginManagerConsentManager->createInstance($plugin_id);
    if ($code = $plugin->getCode()) {
      $build['content'] = [
        '#type' => 'markup',
        '#markup' => $code,
        '#cache' => [
          'tags' => ['consent_manager_' . $plugin_id],
        ],
      ];
    }

    return $build;
  }

}
