<?php

namespace Drupal\consent_manager\Plugin\Derivative;

use Drupal\Component\Plugin\Derivative\DeriverBase;
use Drupal\consent_manager\ConsentManagerPluginManager;
use Drupal\Core\Plugin\Discovery\ContainerDeriverInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides block plugin definitions for all consentmanager blocks.
 */
class ConsentManagerBlock extends DeriverBase implements ContainerDeriverInterface {

  /**
   * The base plugin ID.
   *
   * @var string
   */
  protected $basePluginId;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, $base_plugin_id) {
    return new static(
      $base_plugin_id,
      $container->get('plugin.manager.consent_manager')
    );
  }

  /**
   * Constructs a ConsentManagerBlock object.
   *
   * @param string $base_plugin_id
   *   The base plugin ID.
   * @param \Drupal\consent_manager\ConsentManagerPluginManager $pluginManager
   *   The consent manager plugin manager.
   */
  public function __construct($base_plugin_id, protected ConsentManagerPluginManager $pluginManager) {
    $this->basePluginId = $base_plugin_id;
  }

  /**
   * {@inheritdoc}
   */
  public function getDerivativeDefinitions($base_plugin_definition) {
    $definitions = $this->pluginManager->getBlockDefinitions();
    // Reset the discovered definitions.
    $this->derivatives = [];
    /** @var \Drupal\block_content\Entity\BlockContent $block_content */
    foreach ($definitions as $id => $definition) {
      $this->derivatives[$id] = $base_plugin_definition;
      $this->derivatives[$id]['admin_label'] = $definition['label'];
      $this->derivatives[$id]['config_dependencies']['config'] = [$definition['provider'] . '.settings'];
    }

    return parent::getDerivativeDefinitions($base_plugin_definition);
  }

}
